cap log close
set more off

cd "/Users/ariel/Dropbox/Generalized CES/Chile"

*** Input raw dataset. Chilean firm level data is available at:
*** http://historico.ine.cl/canales/chile_estadistico/estadisticas_economicas/industria/series_estadisticas/series_estadisticas_enia.php

use raw_chile.dta, clear
*** Sales and Input deflators also from ENIA
merge m:1 isic year using sales_deflator.dta
drop if _merge==2
drop _merge
merge m:1 isic year using input_deflator.dta
drop if _merge==2
drop _merge
merge m:1 year using irate_wdi.dta // WDI interest rates for capital expenditure
drop if _merge==2
drop _merge

********** Construct deflated, logged and other measures *********
foreach x in totsales exportvalue totwages va totcapital {
gen d`x' = `x'/(sales_deflator/100)
gen l`x' = ln(d`x')
}

gen sector = floor(isic/100)
gen dmaterials= ((dtotsales-dva)/(input_deflator/100)) 
gen lmaterials= ln(dmaterials)
gen cap_exp = dtotcapital*(.1+(realrate/100)) //real interest rate (WDI). Use 10% as depreciation rate. Capital stock is gross fixed assets. 
gen va_wages = (dva-cap_exp)/dtotwages
gen wages = dtotwages/totalemp
egen meanwages = mean(wages)
gen vaoverwages = (dva-cap_exp)/meanwages 
gen va_emp = vaoverwages/totalemp
gen Markup_pcm = (dva-dtotwages-cap_exp)/(dtotsales) //price-cost margin, or Lerner Index

save data_tranf.dta, replace

*********************************************

************ The following creates Figure 1 in the paper *********************

use data_tranf.dta, clear
keep if year==2004 & va_wages!=. & sector!=27 //Drop the copper industry
gen domsales = totsales-exportvalue
egen meandomsales = mean(domsales)
gen reldomsales = ln(domsales/meandomsales)
label var reldomsales "Sales relative to mean (in logs)"
histogram reldomsales, fc(blue) bc(gray) title("Chilean Domestic Sales, relative to mean, in logs (Data)") xtitle("Sales relative to mean (in logs)")

egen meanmarkup = mean(Markup_pcm)
gen relmark = ln(Markup_pcm/meanmarkup)
histogram relmark, fc(blue) bc(gray) title("Chilean Markups, relative to mean, in logs (Data)") xtitle("Markup relative to mean (in logs)")


*********************************************

************ The following creates the Data Targets for Firm Level Moments (Table 1 panel B) *********************

use data_tranf.dta, clear
keep if year==2004 & va_wages!=. & sector!=27 //Drop the copper industry
gen exporter = (exportvalue>0)
gen lva_wages = ln(va_wages)
keep if year==2004 & va_wages!=. & sector!=27
reg lva_wages exporter 
** This is the "Markup Advantage" of exporters which represents firm productivity as well (see paper for argument).
** We subtract capital expenditure from value added and divide by firm labor compensation. A separate option is to construct markups
** using the method in De Loecker and Warzynski (2012). In this case markup differences are slightly more compressed.
** The reason we divide by firm wages instead of firm employment is that we want to control for firm-specific wages which are constant in the model.
** Therefore, we see this measure as VA/L, but controlling for firm wages.


use data_tranf.dta, clear
keep if year==2004 & totsales!=. & sector!=27 //Drop the copper industry
gen dom_sales = totsales-exportvalue
gen sales_exp=.
gen sales_nx=.
replace sales_exp = dom_sales if exportvalue>0
replace sales_nx = dom_sales if exportvalue==0
drop if totsales==.
collapse (mean) sales_exp sales_nx
gen adv = sales_exp/sales_nx
summ adv
***** Sales advantage of exporters as targeted in the paper.

