%   Exporter Heterogeneity and Price Discrimination: A Quantitative View
%   Jae Wook Jung, Ina Simonovska, and Ariel Weinberger
%
%   code for data generating process
%   modified Michael Waugh and Ina Simonovska (2013), trade_add_err.m

function simul_trdshr = dgp(pred_trdshr,err_var,boot)

Ncountry = length(pred_trdshr);

% index for nonzero elements
itrade = (pred_trdshr(:)~=0);

% generate random draw
stream = RandStream.create('mt19937ar','Seed',06152000+boot);
reset(stream);
RandStream.setGlobalStream(stream);

% initial storage for tradeshare vector
trdshr_vec = zeros(Ncountry^2,1);

% add error term into predicted trade share from the gravity regression   
trdshr_vec(itrade) = exp(log(pred_trdshr(itrade)) + sqrt(err_var).*randn(length(pred_trdshr(itrade)),1));
trdshr_vec(~itrade) = 0;
trdshr_mat = reshape(trdshr_vec,Ncountry,Ncountry);

% normalize the new matrix, sum(tradeshare) = 1 for each country
simul_trdshr = trdshr_mat./repmat(sum(trdshr_mat),Ncountry,1);
end
