%   Exporter Heterogeneity and Price Discrimination: A Quantitative View
%   Jae Wook Jung, Ina Simonovska, and Ariel Weinberger
%
%   subroutine of gravity regression with CEPII gravity data
%   based on Simonovska and Waugh(2014)

function [tssdmat, msdmat, rtausd, techs, err_var]=grav(trdata,cepii,theta)
    
Ncountry = length(trdata);
[m,n]=size(cepii);

% create dummies
xrow = -ones(1,Ncountry-1);
eee=eye(Ncountry-2,Ncountry-2);

dummy = [-ones(Ncountry-2,1) eee];
xrow(1,1)=-2;
dummy = [xrow;dummy];

for i = 1:Ncountry-2
    xrow = -ones(1,Ncountry-1);
    dum = [eee(:,1:i), -ones(Ncountry-2,1), eee(:,i+1:end)];
    xrow(1,i+1) = -2 ;
    dum = [xrow;dum];
    size(dum);
    dummy = [dummy;dum];
end

dummy = [ones(Ncountry-1,Ncountry-1) + eye(Ncountry-1,Ncountry-1);dummy];

asym = eye(Ncountry-1,Ncountry-1);
for i = 1:Ncountry-1
    ass = eye(Ncountry-1,Ncountry-1);
    ass(i,:) = [];
    ass = [-ones(1,Ncountry-1);ass];
    asym = [asym;ass];
end

% trade shares relative to domestic expenditure
trdata = trdata./(repmat(diag(trdata),1,Ncountry))';
hh = (trdata(:)~=0); % nonzero index
ff = (trdata(:)~=1); % one index
trdata = trdata(hh);

% reshape matrix to row vector
dummy1=zeros(m,Ncountry-1);
dummy1(ff,:)=dummy;
dummy=dummy1(hh,:);

dummy1=zeros(m,Ncountry-1);
dummy1(ff,:)=asym;
asym=dummy1(hh,:);

cepii_nz=cepii;
cepii=cepii(hh,:);

% gravity regression
[bsd,~,~,~,statssd] = regress(log(trdata),[dummy asym cepii]);

% reconstruct fitted values
ysd =exp([dummy asym cepii]*bsd);

msdmat = zeros(Ncountry^2,1);
msdmat(hh) = ysd;
msdmat(~ff) = 1; % terms corresponding diagonals should be one(relative to domestic expenditure)

msdmat = reshape(msdmat,Ncountry,Ncountry);
sdc = sum(msdmat);
sdc = repmat(sdc,Ncountry,1);
tssdmat = msdmat./sdc;

% Error Variance
err_var = statssd(end);

% country specific effect (Si)
ssd = [-sum(bsd(1:Ncountry-1));bsd(1:Ncountry-1)];

techs=exp(ssd);

% Construct Trade Costs

bsasym = bsd(Ncountry:end-n);
bsasym = [-sum(bsasym);bsd(Ncountry:end-n)];
beasym = exp(-1./theta.*bsasym)-1;

cefsd = exp(-1./theta.*bsd(end-n+1:end,:))-1;
constant=bsd(end-n+1,:); % constant estimates
dist_elas=bsd(end-n+2,:); % estimates for distance
tdiff_elas=bsd(end-n+3,:); % estimates for time difference

beasym=(beasym(:,:)*ones(1,Ncountry));

rtausd = zeros(Ncountry^2,1);

% trade costs from dummies
dd=1+cepii_nz(:,4).*cefsd(4);
for ii = 5:length(cefsd)
    dd = dd.*(1+cepii_nz(:,ii).*cefsd(ii));
end

% add constant, distance, time_difference variables
dd = dd.*exp(-1./theta.*(cepii_nz(:,1).*constant + cepii_nz(:,2).*dist_elas + cepii_nz(:,3).*tdiff_elas));

beasym = reshape(beasym,[size(cepii_nz,1),1]);
rtausd = dd.*(1+beasym);
rtausd = reshape(rtausd,Ncountry,Ncountry);


end
