%   Exporter Heterogeneity and Price Discrimination: A Quantitative View
%   Jae Wook Jung, Ina Simonovska, and Ariel Weinberger
%
%   code for wage, trade cost (tau) and S(tech)

function [ynew,tech,taus,taustheta,lambdaij,err_var] = est(theta,L,ydata,tradeshareres)


    Ncountry = length(ydata);

% taus and country-specific techtilde from the gravity regression
% tau.^theta from grativity regression is independent from theta, so use initial theta
    [taus,techtilde,lambdaij,~, delta_trade, err_var] = grav_run(theta,tradeshareres);

% Note that the US is the reference country (last row) in cepii dataset used in this code
% rearrange the estimates accordingly
    usref = 62;
    chref = 10;
    taus = ustochile(taus,usref,chref);
    lambdaij = ustochile(lambdaij,usref,chref);
    delta_trade = ustochile(delta_trade,usref,chref);

    techtildetemp = techtilde;
    techtilde(usref,1) = techtildetemp(end,1);
    techtilde(usref+1:end,1) = techtildetemp(usref:end-1,1);
    techtildetemp = techtilde;
    techtilde(end,1) = techtildetemp(chref,1);
    techtilde(chref:end-1,1) = techtildetemp(chref+1:end,1);
    clear techtildetemp

% tau.^theta with estimated taus
    taustheta = taus.^theta; 

% construct income from market clearing condition eq(18) and (19)
    yinitial = ydata(1:Ncountry-1);
    options = optimset('Algorithm','trust-region-reflective','TolFun',eps,'TolX',eps,'Display','off','MaxIter',1000,'MaxFunEvals',50000,'UseParallel','always');
    wage = lsqnonlin(@(x) wage_run1(x,L,Ncountry,lambdaij,delta_trade),yinitial,zeros(size(yinitial)),100.*ones(size(yinitial)),options);

    ynew = [wage;1];
    
    % normalize techtilde to the reference country
    techinitial = techtilde./techtilde(Ncountry);
    techinitial = techinitial(1:Ncountry-1);
    
    techl = lsqnonlin(@(x) tech_run2(x,theta,ynew,L,taus,Ncountry,delta_trade),techinitial,zeros(size(techinitial)),300.*ones(size(techinitial)),options);
    tech = [techl;1];
    % theta is used only for tau.^(-theta). So tech does not depend on theta
    % In order to recover b, use the following equation:
    %   b = (tech./(L.*y.^(-theta))).^(1/theta);

end
