%   Exporter Heterogeneity and Price Discrimination: A Quantitative View
%   Jae Wook Jung, Ina Simonovska, and Ariel Weinberger
%
%   code of generating price difference moments in subroutine
%   1. mean dni
%   2. mean dni_85th
%   3. cov(dni, log(wn/wi))

function mmt = gen_mmts_pricemmt2(rel_price,y,tradeshare,second,Nmmts)

Ncountry = size(rel_price,1);
log_p = log(rel_price);
zzz = isinf(log_p);
%%% some countries have missing price observation. set their log_p very
%%% small but not -Inf
%log_p(zzz) = -10^10;

[~,ng]=size(log_p);

dni = zeros(Ncountry,Ncountry);
dni2 = zeros(Ncountry,Ncountry);
%dni3 = zeros(Ncountry,Ncountry);
%dni4 = zeros(Ncountry,Ncountry);


%sep = round(second./100.*ng + .5);

sizeis = zeros(Ncountry,Ncountry);
for importer = 1:Ncountry
    if length(log_p(importer,~isinf(log_p(importer,:)))) == 1
        mpdiff1 = log_p(importer,~isinf(log_p(importer,:)));
    elseif size(log_p(importer,~isinf(log_p(importer,:))),2) == 0
        mpdiff1 = 0;
    else
    mpdiff1 = nanmean(log_p(importer,~isinf(log_p(importer,:))));
    end
    for exporter = 1:Ncountry

        if length(log_p(exporter,~isinf(log_p(exporter,:)))) == 1
            mpdiff2 = log_p(exporter,~isinf(log_p(exporter,:)));
        elseif size(log_p(exporter,~isinf(log_p(exporter,:))),2) == 0
            mpdiff2 = 0;
        else
        mpdiff2 = nanmean(log_p(exporter,~isinf(log_p(exporter,:))));
        end
        ispositive = intersect(find(zzz(importer,:)==0),find(zzz(exporter,:)==0));
        % Compute the price difference
        pdiff = log_p(importer,ispositive) - log_p(exporter,ispositive);
        
        % Sort them
        [~, h] = sort(pdiff);

        % Now take the max and the 2nd max(85%)
        if ~isempty(ispositive)
        num = pdiff(h(end));
        else
            num = NaN;
        end
            
        if length(ispositive) > 1
        sep = round(second./100.*length(ispositive) + .5);
                num2 = pdiff(h(sep));
        else
        %if length(ispositive) < sep
            num2 = NaN;

        end

        sizeis(exporter,importer) = length(ispositive);


      
        % Compute the mean price difference
        mpdiff = mpdiff1 - mpdiff2;              

        dni(exporter,importer) = num - mpdiff;
        dni2(exporter,importer) = num2 - mpdiff;


    end
end


% exclude domestic entries or possible zero tradeshares
tradeshare(logical(eye(size(tradeshare)))) = 1;
xx = (tradeshare(:) == 1 | tradeshare(:) == 0);

% relative income wn/wi
wnwi = (ones(Ncountry,1)*y')./(y*ones(1,Ncountry));

covdniwnwi = nancov(dni(~xx),log(wnwi(~xx)));

if Nmmts == 3
    mmt = [nanmean(dni(~xx));nanmean(dni2(~xx)); covdniwnwi(2)];
elseif Nmmts == 1
    mmt = [nanmean(dni(~xx))];
end

vv = isinf(mmt);
mmt(vv) = NaN;