%   Exporter Heterogeneity and Price Discrimination: A Quantitative View
%   Jae Wook Jung, Ina Simonovska, and Ariel Weinberger
%
%   main driver for price difference estimation
%
%   This code is written for Matlab R2015a or later.
%   lines using Parallel computing toolbox are not compatible with earlier
%   versions of Matlab than R2015a.



function mmt = gen_pricemmts(rel_price,y,tradeshare,second,Nmmts)
%%%% generate moments about prices
%%%% 1. mean dni
%%%% 2. mean dni_85th
%%%% 3. cov(dni, log(wn/wi))

Ncountry = size(rel_price,1);
log_p = log(rel_price);
zzz = isinf(log_p);
%%% some countries have missing price observation. set their log_p very
%%% small but not -Inf
%log_p(zzz) = -10^10;

[~,ng]=size(log_p);

dni = zeros(Ncountry,Ncountry);
dni2 = zeros(Ncountry,Ncountry);
%dni3 = zeros(Ncountry,Ncountry);
%dni4 = zeros(Ncountry,Ncountry);


%sep = round(second./100.*ng + .5);

sizeis = zeros(Ncountry,Ncountry);
for importer = 1:Ncountry
    if length(log_p(importer,~isinf(log_p(importer,:)))) == 1
        mpdiff1 = log_p(importer,~isinf(log_p(importer,:)));
    elseif size(log_p(importer,~isinf(log_p(importer,:))),2) == 0
        mpdiff1 = 0;
    else
    mpdiff1 = nanmean(log_p(importer,~isinf(log_p(importer,:))));
    end
    for exporter = 1:Ncountry
        %size(log_p(exporter,~isinf(log_p(exporter,:))))%
        %size(log_p(exporter))%
        %exporter
        %importer
        %isinf(log_p(exporter,:))
        %log_p(exporter,~isinf(log_p(exporter,:)))
        %exporter
        %importer
        if length(log_p(exporter,~isinf(log_p(exporter,:)))) == 1
            mpdiff2 = log_p(exporter,~isinf(log_p(exporter,:)));
        elseif size(log_p(exporter,~isinf(log_p(exporter,:))),2) == 0
            mpdiff2 = 0;
        else
        mpdiff2 = nanmean(log_p(exporter,~isinf(log_p(exporter,:))));
        end
        ispositive = intersect(find(zzz(importer,:)==0),find(zzz(exporter,:)==0));
        % Compute the price difference
        pdiff = log_p(importer,ispositive) - log_p(exporter,ispositive);
        
        % Sort them
        [~, h] = sort(pdiff);

        % Now take the max and the 2nd max(85%)
        if ~isempty(ispositive)
        num = pdiff(h(end));
        else
            num = NaN;
        end
            
        if length(ispositive) > 1
        sep = round(second./100.*length(ispositive) + .5);
                num2 = pdiff(h(sep));
        else
        %if length(ispositive) < sep
            num2 = NaN;
            %importer;
            %exporter;
            %length(ispositive);
        %else
        end
        %importer
        %exporter
        sizeis(exporter,importer) = length(ispositive);


      
        % Compute the mean price difference
        mpdiff = mpdiff1 - mpdiff2;              

        dni(exporter,importer) = num - mpdiff;
        dni2(exporter,importer) = num2 - mpdiff;


    end
end
%XX = zeros(size(sizeis));
%XX = XX(sizeis(:,:)<20);
% X = sizeis < 20
% %save ('X50.mat','X')
% csvwrite('X20.csv',X)
% [m,n] = find(X==1)
% pause;
% dni(4,:)=NaN;
% dni(10,:)=NaN;
% dni(18,:)=NaN;
% dni(39,:)=NaN;
% dni(41,:)=NaN;
% dni(53,:)=NaN;
% dni(:,4)=NaN;
% dni(:,10)=NaN;
% dni(:,18)=NaN;
% dni(:,39)=NaN;
% dni(:,41)=NaN;
% dni(:,53)=NaN;
% dni2(4,:)=NaN;
% dni2(10,:)=NaN;
% dni2(18,:)=NaN;
% dni2(39,:)=NaN;
% dni2(41,:)=NaN;
% dni2(53,:)=NaN;
% dni2(:,4)=NaN;
% dni2(:,10)=NaN;
% dni2(:,18)=NaN;
% dni2(:,39)=NaN;
% dni2(:,41)=NaN;
% dni2(:,53)=NaN;
% distance(4,:)=NaN;
% distance(18,:)=NaN;
% distance(39,:)=NaN;
% distance(41,:)=NaN;
% distance(:,4)=NaN;
% distance(:,18)=NaN;
% distance(:,39)=NaN;
% distance(:,41)=NaN;

% exclude domestic entries or possible zero tradeshares
%xx = (tradeshare(:,:) == 1 | tradeshare(:,:) == 0);
%length(find(xx(:)==1))
tradeshare(logical(eye(size(tradeshare)))) = 1;
xx = (tradeshare(:) == 1 | tradeshare(:) == 0);
% length(find(xx(:)==1))
% size(dni)
% dnii = reshape(dni,5041,1);
% dnii(xx) = [];
% size(dnii)

%size(xx)
%isequal(xx,xxx)
% relative income wn/wi
wnwi = (ones(Ncountry,1)*y')./(y*ones(1,Ncountry));
%wnwi2 = (ones(Ncountry,1)*ydata')./(ydata*ones(1,Ncountry));

covdniwnwi = nancov(dni(~xx),log(wnwi(~xx)));
%covdniwnwi2 = nancov(dni(~xx),log(wnwi2(~xx)));
% A = dni(~xx);
% B = log(distance(~xx));
% size(A)
% length(find(A(:)==0))
% pause;
% size(B)
% length(find(B(:)==-Inf))
% % cov(dni,log(dist))
%covdnilogdist = nancov(A,B);
%covdnilogdist = nancov(dni(~xx),log(distance(~xx)));
% if find(log(distance(~xx))==-Inf)
%     disp('-Inf')
%     pause;
% end
% if find(dni(~xx)==0)
%     disp('0')
%     pause;
% end
%mmt = [mean(dni(~xx),'omitnan'); mean(dni2(~xx),'omitnan'); covdniwnwi(2)];
if Nmmts == 3
    mmt = [nanmean(dni(~xx));nanmean(dni2(~xx)); covdniwnwi(2)];
elseif Nmmts == 1
    mmt = [nanmean(dni(~xx))];
end
%mmt = [nanmean(dni(~xx));nanmean(dni2(~xx));covdnilogdist(2)];
vv = isinf(mmt);
mmt(vv) = NaN;