%   Exporter Heterogeneity and Price Discrimination: A Quantitative View
%   Jae Wook Jung, Ina Simonovska, and Ariel Weinberger
%
%   code of objective function

function F = global_zero_pricemmt(x,L,y,tech,taustheta,lambdaij,err_var,mmt_d,rnd,N,flag,boot)


sigma1 = flag.sigma;
weight = flag.weight;
algorithm2 = flag.algorithm2;
sim = flag.sim;
saveW = flag.saveW;
Nmmts = N.mmts;
Nsub = N.sub;
Nsample = N.sample;

if sigma1 == 1
    sigma = 2;
    theta = x;
else
    sigma = x(1);
    theta = x(2);
end

if sigma - 1 > theta % theta should be greater than sigma - 1
    F = 10^10;
else
    
    tic;
    seed = 160326;
    %boot = 122480;
    
    % initial storage for simulated moments
    SSmmts = zeros(Nmmts,Nsample*Nsub);
    
    % initial storage for simulated y, tech, tau^theta, and trade share
    ymat = repmat(y,1,Nsub);
    techmat = repmat(tech,1,Nsub);
    tausthetamat = repmat(taustheta,[1,1,Nsub]);
    trdshrmat = zeros(length(lambdaij),length(lambdaij),Nsub);
    
    for j = 1:Nsub %
        
        if sim == 1
            
            %generate artificial trade share data
            tradeshare = dgp(lambdaij,err_var,j+boot);
            
            [ytemp,techtemp,~,tausthetatemp,trdshrtemp,~] = est(theta,L,y,tradeshare);
            
            ymat(:,j) = ytemp;
            techmat(:,j) = techtemp;
            tausthetamat(:,:,j) = tausthetatemp;
            trdshrmat(:,:,j) = trdshrtemp;
        else
            trdshrmat(:,:,j) = lambdaij;
        end
        
        % generate price difference moments with generated data matrix
        SSmmts(:,(j-1)*Nsample+1:j*Nsample) = gen_mmts_pricemmt(sigma,theta,ymat(:,j),techmat(:,j),tausthetamat(:,:,j),trdshrmat(:,:,j),N,round(seed*rnd(1)),flag);
        
    end
    
    % difference in moments

        mmts_diff = SSmmts-mmt_d*ones(1,Nsub*Nsample);

    % relative errors in moments
    X = mean(mmts_diff,2)./mmt_d;
    
    if weight == 1 % optimal weighting matrix
        
        AA = X*X';
        
        % simulation for optimal weighting matrix
        % the same procedure above with different random seed
        seedN = 160326+170618;
        bootN = 122480+0727;
        NsubN = Nsub;
        SSmmtsN = zeros(Nmmts,Nsample*NsubN);
        
        ymatN = repmat(y,1,NsubN);
        techmatN = repmat(tech,1,NsubN);
        tausthetamatN = repmat(taustheta,[1,1,NsubN]);
        trdshrmatN = zeros(length(lambdaij),length(lambdaij),NsubN);
        
        for j = 1:NsubN
            
            if sim == 1
                tradeshare = dgp(lambdaij,err_var,j+bootN);
                [ytemp,techtemp,~,tausthetatemp,trdshrtemp,~] = est(theta,L,y,tradeshare);
                ymatN(:,j) = ytemp;
                techmatN(:,j) = techtemp;
                tausthetamatN(:,:,j) = tausthetatemp;
                trdshrmatN(:,:,j) = trdshrtemp;
            else
                trdshrmatN(:,:,j) = lambdaij;
            end
            
            SSmmtsN(:,(j-1)*Nsample+1:j*Nsample) = gen_mmts_pricemmt(sigma,theta,ymatN(:,j),techmatN(:,j),tausthetamatN(:,:,j),trdshrmatN(:,:,j),N,round(seedN*rnd(1)),flag);
            
        end
        
        meanN = mean(SSmmtsN,2);
        
        sum_stack = 0;
        for stp = 1:size(SSmmts,2)
            stack = [(SSmmts(:,stp) - meanN)./mmt_d];
            sum_stack = stack*stack' + sum_stack;
        end
        
        BB = (1./size(SSmmts,2)).*sum_stack;
        W = AA + BB; % optimal weighting matrix
        
        % in case using W = I
    elseif weight == 0
        W = eye(length(X));
        
        
        % load optimal W
    elseif weight == 2
        load Weff
    end
    
    %store weight matrix W
    if saveW == 1
        save Weff W
    end
    
    Z = X;
    
    % ignore infinite moments
    iinf = isinf(Z);
    Z(iinf) = NaN;
    
    % function output for different algorithm
    if algorithm2 == 1 %fminsearchbnd
        F = Z'*W*Z;
    elseif algorithm2 == 2 %lsqnonlin
        F = Z;% F = (diag(W).^(1/2)).*Z;
    elseif algorithm2 == 3 % global with lsqnonlin
        F = Z;%     F = (diag(W).^(1/2)).*Z;
    end

    temp = toc;
    disp(['Time to finish one outer loop:' num2str(temp) 'seconds' ])
end

end