%   Exporter Heterogeneity and Price Discrimination: A Quantitative View
%   Jae Wook Jung, Ina Simonovska, and Ariel Weinberger
%
%   gravity regression with CEPII gravity data

function [taus, techs, pred_trdsh, pred_trdsh_norm, delta_trade, err_var]=grav_run(theta,tradeshareres)

% CEPII(http://www.cepii.fr/CEPII/) data set contains all explanatory variables
% starting with a constant, log distance and time different, plus a number of 
% dummies for colonial links, commonality of language/laws and trade agreements
% variables and country names are included in "cepii66.csv"

load('cepii_data.mat')

Ncountry = length(tradeshareres);

%   Estimate the gravity equation and obtain predicted trade shares and other variables
%   pred_trdsh: predicted trade share matrix
%   pred_trdsh_norm: predicted trade share matrix, normalized to domestic
%   tau: trade cost (need to normalize in domestic trade cost = 1)
%   techs: techtilde or country specific effect
%   err_var: estimation error variance

[pred_trdsh, pred_trdsh_norm, tau, techs, err_var]=grav(tradeshareres,cepii,theta);

taus=zeros(Ncountry,Ncountry);

for i=1:Ncountry,
    for j=1:Ncountry,
        taus(i,j) = tau(i,j)./tau(i,i);
    end
end
clear tau

% index for nonzero trade share element
delta_trade=zeros(Ncountry,Ncountry);
delta_trade(tradeshareres(:)>0)= 1;

end